==> nextcloud-25.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/photos/l10n/hr.js <==
OC.L10N.register(
    "photos",
    {
    "Photos" : "Fotografije",
    "Your memories under your control" : "Upravljajte svojim sjećanjima",
    "Videos" : "Videozapisi",
    "People" : "Ljudi",
    "Folders" : "Mape",
    "Favorites" : "Favoriti",
    "Shared with you" : "Podijeljeno s vama",
    "Tags" : "Oznake",
    "Locations" : "Lokacije",
    "Back" : "Natrag",
    "Save" : "Spremi",
    "Copy public link" : "Kopiraj javnu poveznicu",
    "An error occurred" : "Došlo je do pogreške",
    "Open the full size \"{name}\" image" : "Otvori sliku „{name}” u punoj veličini",
    "Open the \"{name}\" sub-directory" : "Otvori poddirektorij „{name}”",
    "Back to {folder}" : "Natrag na {folder}",
    "Share this folder" : "Dijeli ovu mapu",
    "Enable squared photos view" : "Omogući kvadratni prikaz fotografija",
    "View" : "Pregledaj",
    "Favorite" : "Favorit",
    "Remove from favorites" : "Ukloni iz favorita",
    "This folder does not exist" : "Ova mapa ne postoji",
    "No photos in here" : "Ovdje nema fotografija",
    "Shared albums" : "Dijeljeni albumi",
    "No tags yet" : "Još nema oznaka",
    "Photos with tags will show up here" : "Ovdje će se prikazivati fotografije s oznakama",
    "Add" : "Dodaj",
    "Delete selection" : "Izbriši odabir",
    "Tagged photos" : "Označene fotografije",
    "Your photos" : "Vaše fotografije",
    "Your videos" : "Vaši videozapisi",
    "Your folders" : "Vaše mape",
    "Settings" : "Postavke"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");

==> nextcloud-27.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/photos/l10n/hr.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Javna poveznica",
    "Photos" : "Fotografije",
    "Your memories under your control" : "Upravljajte svojim sjećanjima",
    "Videos" : "Videozapisi",
    "People" : "Ljudi",
    "Folders" : "Mape",
    "Favorites" : "Favoriti",
    "Shared with you" : "Podijeljeno s vama",
    "Tags" : "Oznake",
    "Back" : "Natrag",
    "Save" : "Spremi",
    "Shared by" : "Podijeljeno od",
    "No recommendations. Start typing." : "Nema preporuka. Započnite unos.",
    "Copy public link" : "Kopiraj javnu poveznicu",
    "An error occurred" : "Došlo je do pogreške",
    "Open the full size \"{name}\" image" : "Otvori sliku „{name}” u punoj veličini",
    "Open the \"{name}\" sub-directory" : "Otvori poddirektorij „{name}”",
    "Back to {folder}" : "Natrag na {folder}",
    "Share this folder" : "Dijeli ovu mapu",
    "Enable squared photos view" : "Omogući kvadratni prikaz fotografija",
    "View" : "Pregledaj",
    "Favorite" : "Favorit",
    "Remove from favorites" : "Ukloni iz favorita",
    "This folder does not exist" : "Ova mapa ne postoji",
    "No photos in here" : "Ovdje nema fotografija",
    "No tags yet" : "Još nema oznaka",
    "Photos with tags will show up here" : "Ovdje će se prikazivati fotografije s oznakama",
    "Add" : "Dodaj",
    "Delete selection" : "Izbriši odabir",
    "Tagged photos" : "Označene fotografije",
    "Locations" : "Lokacije",
    "Shared albums" : "Dijeljeni albumi"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
